SchemaSpy - Table gnss_data.public.events

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.events | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
event_id | serial | 10 |  | √ | nextval('events_event_id_seq'::regclass) |  |  |
EventDate | timestamp | 29,6 | √ |  | now() |  |  |
EventType | varchar | 6 | √ |  | null |  |  |
EventDescription | text | 2147483647 | √ |  | null |  |  |
Table contained 632,745 rows at Fri Jul 28 14:55 EDT 2017